@@ -45,9 +45,10 @@
 #' \item{tboot}{Type of bootstrap.}
 #' \item{BOOT}{List with all bootstrap replications of \code{tvcoef}, if done.}
 #' \item{call}{Matched call.}
-#' @seealso \code{\link{CI}}, \code{\link{plot}}
+#' 
+#' @seealso \code{\link{bw}}, \code{\link{tvAR}}, \code{\link{confint}}, 
+#' \code{\link{plot}}, \code{\link{print}} and \code{\link{summary}}
 #' @examples
-#' \donttest{
 #' ## Simulate a linear process with time-varying coefficient
 #' ## as functions of scaled time.
 #'
@@ -63,29 +64,40 @@
 #'
 #' coef.lm <- stats::lm(y ~ 0 + X1 + X2, data = data)$coef
 #' model.tvlm <- tvLM(y ~ 0 + X1 + X2, data = data, bw = 0.2)
-#'}
+#'
+#' ## Estimate coefficients of different realized variance models
+#' data("RV")
+#
+#' ##Bollerslev et al. (2016) SHARQ model
+#' SHARQ <- lm (RVt ~ RVt_1_pos + RVt_1_neg + I(RVt_1_pos * RQt_1_sqrt) +
+#' I(RVt_1_neg * RQt_1_sqrt) + RVt_1_5 + RVt_1_22, data = tail(RV, 2000))
+#' 
+#' #Casas et al. (2018) tvSHARQ model
+#' tvSHARQ <- tvLM (RVt ~ RVt_1_pos + RVt_1_neg + RVt_1_5 + RVt_1_22, 
+#' z = tail(RV$RQt_1_sqrt, 2000), data = tail(RV, 2000), bw = 0.002)
 #'
 #' @references 
-#' Cai, Z., Li, Q., Park, J. Y. (2009) Functional-coefficient models for nonstationary 
-#' time series data, \emph{Journal of Econometrics}, Volume 148, pp. 101-113.
+#'  
+#' Bollerslev, T., Patton, A. J. and Quaedvlieg, R. (2016) Exploiting the 
+#' errors: A simple approach for improved volatility forecasting. 
+#' \emph{Journal of Econometrics}, 192, 1-18.
+#' 
+#' Casas, I., Mao, X. and Vega, H. (2018) Reexamining financial and economic 
+#' predictability with new estimators of realized variance and variance 
+#' risk premium. Url= http://pure.au.dk/portal/files/123066669/rp18_10.pdf
 #' 
-#' Robinson, P. (1989) Nonparametric estimation of time-varying parameters.  In
-#' Hackl, P., editor, \emph{Statistical Analysis and Forecasting of Economic Structural
-#' Change}. Springer, Berlin.
-#' @seealso \code{\link{bw}} for bandwidth selection, \code{\link{tvOLS}} for the
-#' estimation procedure and \code{\link{CI}} for confidence intervals.
 #' @keywords time-varying coefficients regression, nonparametric
 #' @export
 
 tvLM<-function (formula, z = NULL, data, bw = NULL, est = c("lc", "ll"), 
                 tkernel = c("Epa", "Gaussian"), singular.ok = TRUE)
 {
-  est <- match.arg(est)
   tkernel <- match.arg(tkernel)
-  if(est %in% c("lc", "ll"))
-    est <- "lc"
-  if(tkernel %in% c("Epa","Gaussian"))
+  est <- match.arg(est)
+  if(!(tkernel %in% c("Epa","Gaussian")))
     tkernel <- "Epa"
+  if(!(est %in% c("lc", "ll")))
+    est <- "lc"
   cl <- match.call()
   mf <- match.call(expand.dots = FALSE)
   m <- match(c("formula", "data"), names(mf), 0L)
